==> edge-login-ui-rn-0.9.23.tgz: package/lib/common/locales/en_US.js <==
export default {
    app_name_default: 'Edge',
    edge_site: 'https://edge.app/',
    login_button: 'Login',
    username: 'Username',
    password: 'Password',
    confirm_password: 'Confirm Password',
    pin: 'PIN',
    back_caps: 'BACK',
    back: 'Back',
    forgot_password: 'Forgot Password',
    create_an_account: 'Create an Account',
    recovery_token: 'Recovery Token',
    initiate_password_recovery: 'Enter Recovery Token. You can find the recovery token in an email that was sent from yourself if password recovery was setup prior to losing access.',
    choose_recovery_question: 'Choose recovery question',
    submit: 'Submit',
    save: 'Save',
    disable: 'Disable',
    disable_password_recovery: 'Disable Password Recovery',
    password_changed: 'Password Changed',
    pwd_change_modal: 'DO NOT FORGET YOUR PASSWORD OR RECOVERY ANSWERS! THEY CANNOT BE RECOVERED!',
    backup_key_label: 'Backup Key',
    ok: 'OK',
    or: 'or',
    to_fix: 'to fix',
    exit: 'Exit',
    exit_pin: 'Exit PIN',
    next_label: 'Next',
    next_label_caps: 'NEXT',
    delete: 'Delete',
    done: 'Done',
    skip: 'SKIP',
    skip_button: 'Skip',
    done_caps: 'DONE',
    cancel: 'Cancel',
    cancel_caps: 'CANCEL',
    enable: 'Enable',
    continue: 'Continue',
    change_password: 'Change Password',
    change_pin: 'Change PIN',
    pin_changed: 'PIN Changed',
    delete_account: 'Delete Account?',
    pin_successfully_changed: 'PIN Successfully Changed',
    delete_account_header: 'Delete Account',
    delete_username_account: 'Delete %1$s on this device? This will disable access via PIN. If 2FA is enabled on this account, this device will not be able to login without a 2FA reset which takes 7 days.',
    disable_otp_header: 'Are you sure you want to disable 2FA?',
    disable_otp_modal_body: '2FA will take 7 days to disable if no action is taken by the account user on authenticated devices.',
    disable_otp_button: 'Disable 2FA',
    send_email_error_header: "Can't send email",
    email_error_modal: "Please set up an email client that is default to your device's OS in order to send a token to yourself",
    password_recovery: 'Password Recovery',
    save_recovery_token: 'Save Recovery Token',
    password_requirements: 'Password Requirements',
    must_ten_characters: 'Must have at least 10 characters',
    must_one_lowercase: 'Must have at least 1 lowercase letter',
    must_one_uppercase: 'Must have at least 1 uppercase letter',
    must_one_number: 'Must have at least 1 number',
    terms_one: 'I understand that my funds are held securely on this device, not by %s',
    terms_two: 'I understand that if I lose this device or uninstall the app, my digital assets can only be recovered with my username and password',
    terms_three: 'I understand that if I lose my username and password, %s will not be able to recover my account, unless I set up password recovery',
    terms_four: 'I understand that I am responsible for safekeeping of my passwords, private key pairs, PIN, and any other codes to access the software. %s is not responsible if my information is compromised or accessed by a 3rd party where funds are lost',
    choose_title_username: 'Choose Username',
    choose_title_password: 'Set Password',
    choose_title_pin: 'Set PIN',
    create_your_account: 'Creating Your Account',
    write_and_store: 'Write Down and Store Securely',
    quick_review: 'Quick Review',
    review: 'Review',
    recovery: 'Recovery',
    account_confirmation: 'Account Confirmation',
    otp_header: 'Two Factor Authentication',
    otp_header_ip: 'Authorize Device',
    otp_header_repair: 'Two Factor Repair',
    recovery_questions_header: 'Recovery Questions',
    account_info_warning: 'You did not set your password. We strongly encourage you to create a password and backup your account as soon as possible. You can set a password in the Settings screen in the app.',
    show_account_info: 'View account information',
    hide_account_info: 'Hide account information',
    password_successfully_changed: 'Password Successfully Changed. DO NOT FORGET YOUR PASSWORD OR RECOVERY ANSWERS! THEY CANNOT BE RECOVERED!',
    otp_hero_scan: 'Scan the QR code below using the device that enabled 2FA to give access to the device',
    password_desc: 'The password is used to log in and change sensitive settings. Don’t forget to write it down.',
    re_enter_new_password: 'Re-enter New Password',
    new_password: 'New Password',
    pswd_and_pin_changed: 'Password and PIN successfully changed.',
    change_pwd_body: "Don't forget your password or recovery answers. You will permanently lose access to your funds if you lose your password and recovery answers.",
    pin_desc: 'Your PIN is a 4 digit code used to quickly log back into your account.',
    recovery_successful: 'Recovery successful! Please change your password and PIN.',
    recover_by_username: 'Please enter the username of the account you want to recover.',
    recovery_by_username_error: 'Invalid recovery link or username does not exist',
    your_answer_label: 'Your Answer',
    answer_case_sensitive: 'Answers are case sensitive',
    answers_four_chanracters: 'Answers should be minimum of 4 characters',
    otp_dispable_req_sent: "2FA disable request has been sent. You'll be able to login with your username and password after 7 days.",
    otp_instructions: 'Sign into your account using the device you setup 2FA with, and go to Settings > 2 Factor Authentication to find the code.',
    disable_otp_button_two: 'Disable 2 Factor Authentication',
    otp_email_body: 'Please click the link below from a mobile device with Edge installed to initiate account recovery for username ',
    otp_email_body2: 'You can also use the Recovery Token displayed below:',
    otp_email_body3: 'Enter or copy and paste the recovery token displayed above inside the Edge app by tapping on Forgot Password at the login screen.',
    otp_email_subject: 'Edge Recovery Token',
    recovery_disabled: 'Password Recovery has been disabled. You can enable it again by going into Password Recovery anytime',
    recovery_what_account: 'Please enter the username of the account you want to recover.',
    email_address: 'Email Address',
    recovery_instructions_complete: 'To complete account recovery setup you MUST save the recovery token. This is required to recover your account in addition to your username and recovery answers. \n\n Please enter your email to be sent the recovery token.',
    recovery_error: 'The answers you provided are incorrect.',
    read_understod_1: 'I have read, understood, and agree to the ',
    read_understod_2: 'Terms of Use',
    last_step_review: 'Last step! Let’s finish with a quick review',
    confirm_email: 'Confirm & Email',
    confirm_share: 'Confirm & Share',
    welcome: 'Welcome to %s!',
    welcome_advantage_one_title: 'Getting started with %s is easy',
    welcome_advantage_one_description: 'You’ll choose a username and password. We’ll use these to encrypt your account.',
    welcome_advantage_two_title: 'Your security is key',
    welcome_advantage_two_description: 'Not even %s has access to your information, so you have full complete control over your digital assets.',
    welcome_advantage_three_description: 'You have complete control over your digital assets.',
    start_username: 'Let’s get started with choosing a username',
    get_started: 'Get Started',
    encrypting: 'Doing the encryption',
    username_desc: 'Your username will be required to sign in to your %s account on this and other devices.',
    almost_done: "Almost done! Let's write down your account information",
    warning_message: 'If you lose your account information, you’ll lose access to your funds permanently.',
    great_job: 'Great Job!',
    hang_tight: 'Hang tight while we create',
    secure_account: 'and secure your account',
    encrypting_wallet: 'Encrypting wallet...',
    confirm_recovery_questions: 'Confirm Recovery',
    login_with_password: 'Login with password',
    landing_tagline: 'The secure and easy to use wallet for your blockchain assets and tokens',
    landing_create_account_button: 'Create account',
    landing_already_have_account: 'Already have an account? Sign in',
    pin_not_enabled: 'PIN is not enabled for this account',
    invalid_pin: 'Invalid PIN',
    pin_network_error_full_password: 'You may still log into your account with username and password.',
    account_locked_for: 'Account locked for \n%1$s more seconds',
    password_error: "Password doesn't meet requirements",
    confirm_password_error: 'Does not match password',
    username_3_characters_error: 'Minimum 3 characters',
    username_ascii_error: 'Must only be ascii characters',
    username_exists_error: 'Username already exists',
    four_digit_pin_error: 'PIN must be four digits',
    it_would_take_xx_to_crack: 'It would take %s to crack your password',
    recommend_choosing_a_stronger: '\nWe recommend choosing a stronger password',
    backup_key_incorrect: 'Backup Key was incorrect',
    create_account_error_title: 'Error occurred creating account',
    create_account_error_message: 'An error occurred creating your account. This may have been due to a slow network connection or network interruption. Please retry and if you receive another error that the account already exists, please restart the app and login with your username and password.',
    try_again: 'Try Again',
    otp_reset_modal_header: 'Secure Your Account',
    otp_reset_modal_message: 'Two factor authentication (2FA) prevents unauthorized access from other devices, even if your username and password is compromised. You can scan a QR code or type in an authentication code to seamlessly authorize other devices. Would you like to enable 2FA?',
    otp_reset_modal_dont_ask: "Don't ask again",
    otp_authentication_header: '2FA has been enabled',
    otp_authentication_message: '2FA has been enabled. A unique authentication code has been generated. If you lose your phone or uninstall the app, it will take 7 days to disable 2FA and access your account from another device without the following authentication code.\n\n%s',
    keypad_one: '1',
    keypad_two: '2',
    keypad_three: '3',
    keypad_four: '4',
    keypad_five: '5',
    keypad_six: '6',
    keypad_seven: '7',
    keypad_eight: '8',
    keypad_nine: '9',
    keypad_zero: '0',
    use_faceId: 'Use Face ID',
    use_touchId: 'Use Touch ID',
    use_fingerprint: 'Use Fingerprint',
    alert_modal_title: 'Security Alerts',
    alert_modal_reset: '2-Factor reset requested for account ',
    alert_modal_voucher: 'Login request for new device for account ',
    alert_modal_action: '\nPlease log in to approve or deny this alert',
    alert_scene_title: 'Security Center',
    alert_scene_message: 'A new device would like to log in to your account.',
    alert_scene_message_many: 'Several new devices would like to log in to your account.',
    alert_scene_warning: 'If you did not request this login, your password may have been stolen and you could lose funds. Please deny the request and change your password.',
    alert_scene_reset_message: 'Someone is trying to remove 2-factor security from your account.',
    alert_scene_reset_date: 'Unless denied, access will be granted on: ',
    alert_scene_ip: 'Location: ',
    alert_scene_device: 'Device: ',
    alert_scene_date: 'Requested on: ',
    alert_scene_approve: 'It was me, grant access',
    alert_scene_deny: 'Not me, deny all',
    otp_scene_header_2fa: 'This device cannot log in because it does not have the right 2-factor code',
    otp_scene_header_ip: 'This device cannot log in due to an unrecognized IP address',
    otp_scene_approve: 'Approve this request from another logged-in device',
    otp_scene_qr: 'Scan QR code with another logged-in device',
    otp_scene_wait: 'Wait until %s when this device will be automatically authorized to log in',
    otp_scene_retrying: 'Retrying login...',
    otp_repair_header_2fa: 'This device cannot sync with the Edge servers because it does not have the right 2-factor code',
    otp_repair_header_ip: 'This device cannot sync with the Edge servers due to an unrecognized IP address',
    otp_backup_code_modal_title: 'Enter Backup Code',
    qr_modal_title: 'Scan QR Code',
    qr_modal_message: 'Scan this QR code with another device logged into your account:',
    qr_modal_started: 'Logging into account %s',
    // Alert component:
    alert_dropdown_alert: 'Alert! ',
    alert_dropdown_warning: 'Warning! ',
    // Notifications Permissions
    notifications_permissions_ios: 'Please enable notifications and background app refresh for account security. Edge will notify you if other devices attempt to access your account and will allow you to accept or reject access.',
    notifications_permissions_android: 'Please enable notifications for account security. Edge will notify you if other devices attempt to access your account and will allow you to accept or reject access.',
    change_recovery_question1: 'What is the anniversary date with your first spouse?',
    change_recovery_question2: 'What is the birthdate of the maid/matron of honor at your wedding?',
    change_recovery_question3: 'What is the birthdate of your childhood best friend?',
    change_recovery_question4: 'What was your favorite brand of clothing in high school?',
    change_recovery_question5: 'What is the birthdate of your favorite grand parent?',
    change_recovery_question6: 'What is the birthdate of your favorite niece or nephew?',
    change_recovery_question7: 'What was the first address you remember living in?',
    change_recovery_question8: 'What was your address in college?',
    change_recovery_question9: "What was your maternal grandfather's first and last name?",
    change_recovery_question10: "What was your maternal grandmother's first and last name?",
    change_recovery_question11: 'What is the street address of the first home you remember?',
    change_recovery_question12: 'Name the make, model, and year of your dream car?',
    change_recovery_question13: 'Who is your childhood sports hero?'
};

==> edge-login-ui-rn-0.9.27.tgz: package/lib/common/locales/en_US.js <==
export default {
    app_name_default: 'Edge',
    edge_site: 'https://edge.app/',
    login_button: 'Login',
    username: 'Username',
    password: 'Password',
    confirm_password: 'Confirm Password',
    confirm: 'Confirm',
    create: 'Create',
    pin: 'PIN',
    back_caps: 'BACK',
    back: 'Back',
    forgot_password: 'Forgot Password',
    create_an_account: 'Create an Account',
    recovery_token: 'Recovery Token',
    initiate_password_recovery: 'Enter Recovery Token. You can find the recovery token in an email that was sent from yourself if password recovery was setup prior to losing access.',
    choose_recovery_question: 'Choose recovery question',
    submit: 'Submit',
    save: 'Save',
    disable: 'Disable',
    disable_password_recovery: 'Disable Password Recovery',
    password_changed: 'Password Changed',
    pwd_change_modal: 'DO NOT FORGET YOUR PASSWORD OR RECOVERY ANSWERS! THEY CANNOT BE RECOVERED!',
    backup_key_label: 'Backup Key',
    ok: 'OK',
    or: 'or',
    to_fix: 'to fix',
    exit: 'Exit',
    exit_pin: 'Exit PIN',
    next_label: 'Next',
    next_label_caps: 'NEXT',
    delete: 'Delete',
    done: 'Done',
    skip: 'SKIP',
    skip_button: 'Skip',
    done_caps: 'DONE',
    cancel: 'Cancel',
    cancel_caps: 'CANCEL',
    enable: 'Enable',
    continue: 'Continue',
    change_password: 'Change Password',
    change_pin: 'Change PIN',
    pin_changed: 'PIN Changed',
    delete_account: 'Delete Account?',
    pin_successfully_changed: 'PIN Successfully Changed',
    delete_account_header: 'Delete Account',
    delete_username_account: 'Delete %1$s on this device? This will disable access via PIN. If 2FA is enabled on this account, this device will not be able to login without a 2FA reset which takes 7 days.',
    disable_otp_header: 'Are you sure you want to disable 2FA?',
    disable_otp_modal_body: '2FA will take 7 days to disable if no action is taken by the account user on authenticated devices.',
    disable_otp_button: 'Disable 2FA',
    send_email_error_header: "Can't send email",
    email_error_modal: "Please set up an email client that is default to your device's OS in order to send a token to yourself",
    password_recovery: 'Password Recovery',
    save_recovery_token: 'Save Recovery Token',
    password_requirements: 'Password Requirements',
    must_ten_characters: 'Must have at least 10 characters',
    must_one_lowercase: 'Must have at least 1 lowercase letter',
    must_one_uppercase: 'Must have at least 1 uppercase letter',
    must_one_number: 'Must have at least 1 number',
    terms_one: 'I understand that my funds are held securely on this device, not by %s',
    terms_two: 'I understand that if I lose this device or uninstall the app, my digital assets can only be recovered with my username and password',
    terms_three: 'I understand that if I lose my username and password, %s will not be able to recover my account, unless I set up password recovery',
    terms_four: 'I understand that I am responsible for safekeeping of my passwords, private key pairs, PIN, and any other codes to access the software. %s is not responsible if my information is compromised or accessed by a 3rd party where funds are lost',
    choose_title_username: 'Choose Username',
    choose_title_password: 'Set Password',
    choose_title_pin: 'Set PIN',
    create_your_account: 'Creating Your Account',
    write_and_store: 'Write Down and Store Securely',
    quick_review: 'Quick Review',
    review: 'Review',
    recovery: 'Recovery',
    account_confirmation: 'Account Confirmation',
    otp_header: 'Two Factor Authentication',
    otp_header_ip: 'Authorize Device',
    otp_header_repair: 'Two Factor Repair',
    recovery_questions_header: 'Recovery Questions',
    account_info_warning: 'You did not set your password. We strongly encourage you to create a password and backup your account as soon as possible. You can set a password in the Settings screen in the app.',
    show_account_info: 'View account information',
    hide_account_info: 'Hide account information',
    password_successfully_changed: 'Password Successfully Changed. DO NOT FORGET YOUR PASSWORD OR RECOVERY ANSWERS! THEY CANNOT BE RECOVERED!',
    otp_hero_scan: 'Scan the QR code below using the device that enabled 2FA to give access to the device',
    password_desc: 'The password is used to log in and change sensitive settings. Be sure to write it down!',
    re_enter_new_password: 'Re-enter New Password',
    new_password: 'New Password',
    pswd_and_pin_changed: 'Password and PIN successfully changed.',
    change_pwd_body: "Don't forget your password or recovery answers. You will permanently lose access to your funds if you lose your password and recovery answers.",
    pin_desc: 'Your PIN is a 4 digit code used to quickly log back into your account.',
    recovery_successful: 'Recovery successful! Please change your password and PIN.',
    recover_by_username: 'Please enter the username of the account you want to recover.',
    recovery_by_username_error: 'Invalid recovery link or username does not exist',
    your_answer_label: 'Your Answer',
    answer_case_sensitive: 'Answers are case sensitive',
    answers_four_chanracters: 'Answers should be minimum of 4 characters',
    otp_dispable_req_sent: "2FA disable request has been sent. You'll be able to login with your username and password after 7 days.",
    otp_instructions: 'Sign into your account using the device you setup 2FA with, and go to Settings > 2 Factor Authentication to find the code.',
    disable_otp_button_two: 'Disable 2 Factor Authentication',
    otp_email_body: 'Please click the link below from a mobile device with Edge installed to initiate account recovery for username ',
    otp_email_body2: 'You can also use the Recovery Token displayed below:',
    otp_email_body3: 'Enter or copy and paste the recovery token displayed above inside the Edge app by tapping on Forgot Password at the login screen.',
    otp_email_subject: 'Edge Recovery Token',
    recovery_disabled: 'Password Recovery has been disabled. You can enable it again by going into Password Recovery anytime',
    recovery_what_account: 'Please enter the username of the account you want to recover.',
    email_address: 'Email Address',
    recovery_instructions_complete: 'To complete account recovery setup you MUST save the recovery token. This is required to recover your account in addition to your username and recovery answers. \n\n Please enter your email to be sent the recovery token.',
    recovery_error: 'The answers you provided are incorrect.',
    read_understod_1: 'I have read, understood, and agree to the ',
    read_understod_2: 'Terms of Use',
    last_step_review: 'Last step! Let’s finish with a quick review',
    confirm_email: 'Confirm & Email',
    confirm_share: 'Confirm & Share',
    welcome: 'Welcome to %s!',
    welcome_advantage_one_title: 'Getting started with %s is easy',
    welcome_advantage_one_description_line1: 'You’ll choose a username and password.',
    welcome_advantage_one_description_line2: 'We’ll use these to encrypt your account.',
    welcome_advantage_two_title: 'Your security is key',
    welcome_advantage_two_description: 'You have complete control over your digital assets. Not even %s has access to your information.',
    start_username: 'Let’s get started with choosing a username',
    get_started: 'Get Started',
    encrypting: 'Doing the encryption',
    username_desc: 'Your username will be required to sign in to your %s account on this and other devices.',
    almost_done: "Almost done! Let's write down your account information",
    warning_message: 'If you lose your account information, you’ll lose access to your funds permanently.',
    great_job: 'Great Job!',
    hang_tight: 'Hang tight while we create',
    secure_account: 'and secure your account',
    encrypting_wallet: 'Encrypting wallet...',
    confirm_recovery_questions: 'Confirm Recovery',
    login_with_password: 'Login with password',
    landing_tagline: 'The secure and easy to use wallet for your blockchain assets and tokens',
    landing_create_account_button: 'Create account',
    landing_already_have_account: 'Already have an account? Sign in',
    pin_not_enabled: 'PIN is not enabled for this account',
    invalid_pin: 'Invalid PIN',
    pin_network_error_full_password: 'You may still log into your account with username and password.',
    account_locked_for: 'Account locked for \n%1$s more seconds',
    password_error: "Password doesn't meet requirements",
    confirm_password_error: 'Does not match password',
    username_3_characters_error: 'Minimum 3 characters',
    username_ascii_error: 'Must only be ascii characters',
    username_exists_error: 'Username already exists',
    four_digit_pin_error: 'PIN must be four digits',
    it_would_take_xx_to_crack: 'It would take %s to crack your password',
    recommend_choosing_a_stronger: '\nWe recommend choosing a stronger password',
    backup_key_incorrect: 'Backup Key was incorrect',
    create_account_error_title: 'Error occurred creating account',
    create_account_error_message: 'An error occurred creating your account. This may have been due to a slow network connection or network interruption. Please retry and if you receive another error that the account already exists, please restart the app and login with your username and password.',
    try_again: 'Try Again',
    otp_reset_modal_header: 'Secure Your Account',
    otp_reset_modal_message: 'Two factor authentication (2FA) prevents unauthorized access from other devices, even if your username and password is compromised. You can scan a QR code or type in an authentication code to seamlessly authorize other devices. Would you like to enable 2FA?',
    otp_reset_modal_dont_ask: "Don't ask again",
    otp_authentication_header: '2FA has been enabled',
    otp_authentication_message: '2FA has been enabled. A unique authentication code has been generated. If you lose your phone or uninstall the app, it will take 7 days to disable 2FA and access your account from another device without the following authentication code.\n\n%s',
    keypad_one: '1',
    keypad_two: '2',
    keypad_three: '3',
    keypad_four: '4',
    keypad_five: '5',
    keypad_six: '6',
    keypad_seven: '7',
    keypad_eight: '8',
    keypad_nine: '9',
    keypad_zero: '0',
    use_faceId: 'Use Face ID',
    use_touchId: 'Use Touch ID',
    use_fingerprint: 'Use Fingerprint',
    alert_modal_title: 'Security Alerts',
    alert_modal_reset: '2-Factor reset requested for account ',
    alert_modal_voucher: 'Login request for new device for account ',
    alert_modal_action: '\nPlease log in to approve or deny this alert',
    alert_scene_title: 'Security Center',
    alert_scene_message: 'A new device would like to log in to your account.',
    alert_scene_message_many: 'Several new devices would like to log in to your account.',
    alert_scene_warning: 'If you did not request this login, your password may have been stolen and you could lose funds. Please deny the request and change your password.',
    alert_scene_reset_message: 'Someone is trying to remove 2-factor security from your account.',
    alert_scene_reset_date: 'Unless denied, access will be granted on: ',
    alert_scene_ip: 'Location: ',
    alert_scene_device: 'Device: ',
    alert_scene_date: 'Requested on: ',
    alert_scene_approve: 'It was me, grant access',
    alert_scene_deny: 'Not me, deny all',
    otp_scene_header_2fa: 'This device cannot log in because it does not have the right 2-factor code',
    otp_scene_header_ip: 'This device cannot log in due to an unrecognized IP address',
    otp_scene_approve: 'Approve this request from another logged-in device',
    otp_scene_qr: 'Scan QR code with another logged-in device',
    otp_scene_wait: 'Wait until %s when this device will be automatically authorized to log in',
    otp_scene_retrying: 'Retrying login...',
    otp_repair_header_2fa: 'This device cannot sync with the Edge servers because it does not have the right 2-factor code',
    otp_repair_header_ip: 'This device cannot sync with the Edge servers due to an unrecognized IP address',
    otp_backup_code_modal_title: 'Enter Backup Code',
    qr_modal_title: 'Scan QR Code',
    qr_modal_message: 'Scan this QR code with another device logged into your account:',
    qr_modal_started: 'Logging into account %s',
    // Alert component:
    alert_dropdown_alert: 'Alert! ',
    alert_dropdown_warning: 'Warning! ',
    // Notifications Permissions
    notifications_permissions_ios: 'Please enable notifications and background app refresh for account security. Edge will notify you if other devices attempt to access your account and will allow you to accept or reject access.',
    notifications_permissions_android: 'Please enable notifications for account security. Edge will notify you if other devices attempt to access your account and will allow you to accept or reject access.',
    change_recovery_question1: 'What is the anniversary date with your first spouse?',
    change_recovery_question2: 'What is the birthdate of the maid/matron of honor at your wedding?',
    change_recovery_question3: 'What is the birthdate of your childhood best friend?',
    change_recovery_question4: 'What was your favorite brand of clothing in high school?',
    change_recovery_question5: 'What is the birthdate of your favorite grand parent?',
    change_recovery_question6: 'What is the birthdate of your favorite niece or nephew?',
    change_recovery_question7: 'What was the first address you remember living in?',
    change_recovery_question8: 'What was your address in college?',
    change_recovery_question9: "What was your maternal grandfather's first and last name?",
    change_recovery_question10: "What was your maternal grandmother's first and last name?",
    change_recovery_question11: 'What is the street address of the first home you remember?',
    change_recovery_question12: 'Name the make, model, and year of your dream car?',
    change_recovery_question13: 'Who is your childhood sports hero?'
};
